@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Any, Callable, TypeVar
+from typing import Any, Callable, TypeVar, overload
 import inspect
 
 _R = TypeVar("_R")
@@ -11,9 +11,27 @@ class Storage:
     _INSTANCES: dict[str, Storage] = {}
 
     def __init__(self):
-        self._varmap: dict[str, Callable[[], Any]] = {}
+        self._varmap: dict[str, Callable[..., Any]] = {}
+
+    @overload
+    def mark_getter(self, func: Callable[..., Any]) -> Callable[..., Any]:
+        ...
+
+    @overload
+    def mark_getter(
+        self, name: str
+    ) -> Callable[[Callable[..., Any]], Callable[..., Any]]:
+        ...
+
+    def mark_getter(self, name, func=None):
+        if callable(name) and func is None:
+            func = name
+            name = func.__name__
+        elif isinstance(name, str):
+            pass
+        else:
+            raise TypeError(f"Invalid type for name: {type(name)}")
 
-    def mark_getter(self, name: str, func: Callable[[], Any] | None = None):
         def wrapper(f: Callable[[], Any]):
             self._varmap[name] = f
             return f
@@ -32,11 +50,12 @@ class Storage:
     def call(self, func: Callable[..., _R], parent=None) -> _R:
         """Call a function with variables from the storage."""
         args = []
-        for v in inspect.signature(func).parameters.keys():
+
+        for v in inspect.getargs(func.__code__).args:
             if v == "self" and parent is not None:
                 args.append(parent)
             elif getter := self._varmap.get(v, None):
-                args.append(getter())
+                args.append(self.call(getter, parent=parent))
             else:
                 raise ValueError(f"Variable {v} not found in storage")
         return func(*args)
